//////////////////////////////////////////////////////////////////////////////
// Name:        SVGTests.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_TESTS_H
#define WX_SVG_TESTS_H

#include "SVGStringList.h"
#include "String_wxsvg.h"
#include "Element.h"

class wxSVGTests
{
  protected:
    wxSVGStringList m_requiredFeatures;
    wxSVGStringList m_requiredExtensions;
    wxSVGStringList m_systemLanguage;

  public:
    inline const wxSVGStringList& GetRequiredFeatures() const { return m_requiredFeatures; }
    inline void SetRequiredFeatures(const wxSVGStringList& n) { m_requiredFeatures = n; }

    inline const wxSVGStringList& GetRequiredExtensions() const { return m_requiredExtensions; }
    inline void SetRequiredExtensions(const wxSVGStringList& n) { m_requiredExtensions = n; }

    inline const wxSVGStringList& GetSystemLanguage() const { return m_systemLanguage; }
    inline void SetSystemLanguage(const wxSVGStringList& n) { m_systemLanguage = n; }

  public:
    virtual ~wxSVGTests() {}
    virtual bool HasExtension(const wxString& extension);
    bool HasAttribute(const wxString& name) const;
    wxString GetAttribute(const wxString& name) const;
    bool SetAttribute(const wxString& name, const wxString& value);
    wxSvgXmlAttrHash GetAttributes() const;
};

#endif // WX_SVG_TESTS_H
