//////////////////////////////////////////////////////////////////////////////
//// Name:        SVGCoordinates.h
//// Purpose:
//// Author:      Alex Thuering
//// Created:     2006/01/07
//// RCS-ID:      $Id: SVGCoordinates.h,v 1.1 2006/01/08 12:31:03 ntalex Exp $
//// Copyright:   (c) 2006 Alex Thuering
//// Licence:     wxWindows licence
////////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_COORDINATES_H
#define WX_SVG_COORDINATES_H

enum wxSVG_COORDINATES
{
  wxSVG_COORDINATES_USER = 0,
  wxSVG_COORDINATES_VIEWPORT = 1,
  wxSVG_COORDINATES_SCREEN = 2
};

#endif // WX_SVG_COORDINATES_H

