//////////////////////////////////////////////////////////////////////////////
// Name:        SVGUnitTypes.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_UNIT_TYPES_H
#define WX_SVG_UNIT_TYPES_H


enum wxSVG_UNIT_TYPE
{
  wxSVG_UNIT_TYPE_UNKNOWN = 0,
  wxSVG_UNIT_TYPE_USERSPACEONUSE = 1,
  wxSVG_UNIT_TYPE_OBJECTBOUNDINGBOX = 2
};

class wxSVGUnitTypes
{
  public:
    virtual ~wxSVGUnitTypes() {}
};

#endif // WX_SVG_UNIT_TYPES_H
