//////////////////////////////////////////////////////////////////////////////
// Name:        CSSValues.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genCSS.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_CSS_VALUES_H
#define WX_CSS_VALUES_H

enum wxCSS_VALUE
{
  wxCSS_VALUE_UNKNOWN,
  wxCSS_VALUE_100,
  wxCSS_VALUE_200,
  wxCSS_VALUE_300,
  wxCSS_VALUE_400,
  wxCSS_VALUE_500,
  wxCSS_VALUE_600,
  wxCSS_VALUE_700,
  wxCSS_VALUE_800,
  wxCSS_VALUE_900,
  wxCSS_VALUE_ACCUMULATE,
  wxCSS_VALUE_AFTER_EDGE,
  wxCSS_VALUE_ALL,
  wxCSS_VALUE_ALPHABETIC,
  wxCSS_VALUE_AUTO,
  wxCSS_VALUE_BASELINE,
  wxCSS_VALUE_BEFORE_EDGE,
  wxCSS_VALUE_BEVEL,
  wxCSS_VALUE_BIDI_OVERRIDE,
  wxCSS_VALUE_BLINK,
  wxCSS_VALUE_BLOCK,
  wxCSS_VALUE_BOLD,
  wxCSS_VALUE_BOLDER,
  wxCSS_VALUE_BUTT,
  wxCSS_VALUE_CENTRAL,
  wxCSS_VALUE_COLLAPSE,
  wxCSS_VALUE_COMPACT,
  wxCSS_VALUE_CONDENSED,
  wxCSS_VALUE_CRISPEDGES,
  wxCSS_VALUE_CROSSHAIR,
  wxCSS_VALUE_CURRENTCOLOR,
  wxCSS_VALUE_DEFAULT,
  wxCSS_VALUE_E_RESIZE,
  wxCSS_VALUE_EMBED,
  wxCSS_VALUE_END,
  wxCSS_VALUE_EVENODD,
  wxCSS_VALUE_EXPANDED,
  wxCSS_VALUE_EXTRA_CONDENSED,
  wxCSS_VALUE_EXTRA_EXPANDED,
  wxCSS_VALUE_FILL,
  wxCSS_VALUE_GEOMETRICPRECISION,
  wxCSS_VALUE_HANGING,
  wxCSS_VALUE_HELP,
  wxCSS_VALUE_HIDDEN,
  wxCSS_VALUE_IDEOGRAPHIC,
  wxCSS_VALUE_INLINE,
  wxCSS_VALUE_INLINE_TABLE,
  wxCSS_VALUE_ITALIC,
  wxCSS_VALUE_LIGHTER,
  wxCSS_VALUE_LINE_THROUGH,
  wxCSS_VALUE_LINEARRGB,
  wxCSS_VALUE_LIST_ITEM,
  wxCSS_VALUE_LR,
  wxCSS_VALUE_LR_TB,
  wxCSS_VALUE_LTR,
  wxCSS_VALUE_MARKER,
  wxCSS_VALUE_MATHEMATICAL,
  wxCSS_VALUE_MIDDLE,
  wxCSS_VALUE_MITER,
  wxCSS_VALUE_MOVE,
  wxCSS_VALUE_N_RESIZE,
  wxCSS_VALUE_NARROWER,
  wxCSS_VALUE_NE_RESIZE,
  wxCSS_VALUE_NEW,
  wxCSS_VALUE_NO_CHANGE,
  wxCSS_VALUE_NONE,
  wxCSS_VALUE_NONZERO,
  wxCSS_VALUE_NORMAL,
  wxCSS_VALUE_NW_RESIZE,
  wxCSS_VALUE_OBLIQUE,
  wxCSS_VALUE_OPTIMIZELEGIBILITY,
  wxCSS_VALUE_OPTIMIZEQUALITY,
  wxCSS_VALUE_OPTIMIZESPEED,
  wxCSS_VALUE_OVERLINE,
  wxCSS_VALUE_PAINTED,
  wxCSS_VALUE_POINTER,
  wxCSS_VALUE_RESET_SIZE,
  wxCSS_VALUE_RL,
  wxCSS_VALUE_RL_TB,
  wxCSS_VALUE_ROUND,
  wxCSS_VALUE_RTL,
  wxCSS_VALUE_RUN_IN,
  wxCSS_VALUE_S_RESIZE,
  wxCSS_VALUE_SRGB,
  wxCSS_VALUE_SCROLL,
  wxCSS_VALUE_SE_RESIZE,
  wxCSS_VALUE_SEMI_CONDENSED,
  wxCSS_VALUE_SEMI_EXPANDED,
  wxCSS_VALUE_SMALL_CAPS,
  wxCSS_VALUE_SQUARE,
  wxCSS_VALUE_START,
  wxCSS_VALUE_STROKE,
  wxCSS_VALUE_SUB,
  wxCSS_VALUE_SUPER,
  wxCSS_VALUE_SW_RESIZE,
  wxCSS_VALUE_TABLE,
  wxCSS_VALUE_TABLE_CAPTION,
  wxCSS_VALUE_TABLE_CELL,
  wxCSS_VALUE_TABLE_COLUMN,
  wxCSS_VALUE_TABLE_COLUMN_GROUP,
  wxCSS_VALUE_TABLE_FOOTER_GROUP,
  wxCSS_VALUE_TABLE_HEADER_GROUP,
  wxCSS_VALUE_TABLE_ROW,
  wxCSS_VALUE_TABLE_ROW_GROUP,
  wxCSS_VALUE_TB,
  wxCSS_VALUE_TB_RL,
  wxCSS_VALUE_TEXT,
  wxCSS_VALUE_TEXT_AFTER_EDGE,
  wxCSS_VALUE_TEXT_BEFORE_EDGE,
  wxCSS_VALUE_ULTRA_CONDENSED,
  wxCSS_VALUE_ULTRA_EXPANDED,
  wxCSS_VALUE_UNDERLINE,
  wxCSS_VALUE_USE_SCRIPT,
  wxCSS_VALUE_VISIBLE,
  wxCSS_VALUE_VISIBLEFILL,
  wxCSS_VALUE_VISIBLEPAINTED,
  wxCSS_VALUE_VISIBLESTROKE,
  wxCSS_VALUE_W_RESIZE,
  wxCSS_VALUE_WAIT,
  wxCSS_VALUE_WIDER
};

#endif // WX_CSS_VALUES_H
