//////////////////////////////////////////////////////////////////////////////
// Name:        SVGElementInstanceList.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genList.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_ELEMENT_INSTANCE_LIST_H
#define WX_SVG_ELEMENT_INSTANCE_LIST_H

#include "SVGElementInstance.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(wxSVGElementInstance, wxSVGElementInstanceList);

#endif // WX_SVG_ELEMENT_INSTANCE_LIST_H
