//////////////////////////////////////////////////////////////////////////////
// Name:        SVGFilterPrimitiveStandardAttributes.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_FILTER_PRIMITIVE_STANDARD_ATTRIBUTES_H
#define WX_SVG_FILTER_PRIMITIVE_STANDARD_ATTRIBUTES_H

#include "SVGStylable.h"
#include "SVGAnimatedLength.h"
#include "SVGAnimatedString.h"
#include "String_wxsvg.h"
#include "Element.h"
#include "SVGAnimatedType.h"

class wxSVGFilterPrimitiveStandardAttributes:
  public wxSVGStylable
{
  protected:
    wxSVGAnimatedLength m_x;
    wxSVGAnimatedLength m_y;
    wxSVGAnimatedLength m_width;
    wxSVGAnimatedLength m_height;
    wxSVGAnimatedString m_result;

  public:
    inline const wxSVGAnimatedLength& GetX() const { return m_x; }
    inline void SetX(const wxSVGAnimatedLength& n) { m_x = n; }
    inline void SetX(const wxSVGLength& n) { m_x.SetBaseVal(n); }

    inline const wxSVGAnimatedLength& GetY() const { return m_y; }
    inline void SetY(const wxSVGAnimatedLength& n) { m_y = n; }
    inline void SetY(const wxSVGLength& n) { m_y.SetBaseVal(n); }

    inline const wxSVGAnimatedLength& GetWidth() const { return m_width; }
    inline void SetWidth(const wxSVGAnimatedLength& n) { m_width = n; }
    inline void SetWidth(const wxSVGLength& n) { m_width.SetBaseVal(n); }

    inline const wxSVGAnimatedLength& GetHeight() const { return m_height; }
    inline void SetHeight(const wxSVGAnimatedLength& n) { m_height = n; }
    inline void SetHeight(const wxSVGLength& n) { m_height.SetBaseVal(n); }

    inline const wxSVGAnimatedString& GetResult() const { return m_result; }
    inline void SetResult(const wxSVGAnimatedString& n) { m_result = n; }
    inline void SetResult(const wxString& n) { m_result.SetBaseVal(n); }

  public:
    virtual ~wxSVGFilterPrimitiveStandardAttributes() {}
    bool HasAttribute(const wxString& name) const;
    wxString GetAttribute(const wxString& name) const;
    bool SetAttribute(const wxString& name, const wxString& value);
    wxSvgXmlAttrHash GetAttributes() const;
    bool SetAnimatedValue(const wxString& name, const wxSVGAnimatedType& value);
};

#endif // WX_SVG_FILTER_PRIMITIVE_STANDARD_ATTRIBUTES_H
