//////////////////////////////////////////////////////////////////////////////
// Name:        SVGNumberList.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genList.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_NUMBER_LIST_H
#define WX_SVG_NUMBER_LIST_H

#include "String_wxsvg.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(float, wxSVGNumberListBase);

class wxSVGNumberList: public wxSVGNumberListBase
{
  public:
    wxSVGNumberList() {}
    
    wxString GetValueAsString() const;
    void SetValueAsString(const wxString& value);
};

#endif // WX_SVG_NUMBER_LIST_H
