//////////////////////////////////////////////////////////////////////////////
// Name:        NodeList.h
// Purpose:     
// Author:      Alex Thuering
// Created:     2005/04/29
// RCS-ID:      $Id: NodeList.h,v 1.2 2005/07/30 12:09:05 etisserant Exp $
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
//////////////////////////////////////////////////////////////////////////////

#ifndef wxSVG_NODE_LIST_H
#define wxSVG_NODE_LIST_H

#include "SVGElement.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(wxSVGElement*, wxNodeList);

#endif //wxSVG_NODE_LIST_H
