//////////////////////////////////////////////////////////////////////////////
// Name:        ElementTimeControl.h
// Purpose:     
// Author:      Alex Thuering
// Created:     2005/04/29
// RCS-ID:      $Id: ElementTimeControl.h,v 1.1.1.1 2005/05/10 17:51:11 ntalex Exp $
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
//////////////////////////////////////////////////////////////////////////////

#ifndef wxSVG_ELEMENT_TIME_CONTROL_H
#define wxSVG_ELEMENT_TIME_CONTROL_H

struct wxElementTimeControl {};

#endif //wxSVG_ELEMENT_TIME_CONTROL_H

